# coding: utf-8
# Licensed under a 3-clause BSD style license - see LICENSE.rst

"""NumPy functions and classes needed for astropy but not available
in all supported NumPy versions.  See docs/utils/numpy.rst for details.
"""

from __future__ import division, absolute_import, unicode_literals

from .lib.stride_tricks import broadcast_arrays, broadcast_to
